	import { csv } from 'd3';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';

// Colors for the sections in Pie Chart
const sectionColors = [
  		'Aquamarine','silver', 'olive', 'coral', 'skyblue', 'crimson', 'blue', 'lavender', 'aqua','Mistyrose'
		  ];

// Data set URI
const csvUrl = 'https://gist.githubusercontent.com/prashanthyamala/8c18401363475f93ea8e1f87758faa5b/raw/2ff118d3f3cae804fc44e7bcc5297f2dd173534e/ice_7.csv';

// Function to fetch data from the URI
const fetchData = async () => {
  const data = await csv(csvUrl);
  return data;
};

// Select the SVG from the HTML body
const svg = select("svg");
const width = + svg.attr('width');
const height = + svg.attr('height');

// Format axes text
const xAxisTickFormat = number =>
  	format('.4~g')(number);

// Render Pie Chart on the canvas
const render = (data, total) => {
  const pieData = pie().value(d=>d.Valuation_billions)(data);
  const colors = scaleOrdinal()
  	.domain(data)
  	.range(sectionColors);
  
  // Object for generating Arcs of the sections
  const arcGenerator = d3.arc()
  .innerRadius(0)
  .outerRadius(250);

  // Segments are the partition in the Pie Chart
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(175)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  
  sections.enter()
    .append("path")
    .attr("d", segments)
  	.attr("fill", d => colors(d.data.Valuation_billions));
  
  // Render text on each section
  sections
    .enter()
    .append('text')
    .text(d => xAxisTickFormat((d.data.Valuation_billions))+"B")
    .attr("transform", function(d) { return "translate(" + arcGenerator.centroid(d) + ")";  })
    .style("text-anchor", "middle")
  	.style('fill', 'black')
    .style("font-size", 15);
  
  // Render legend for the data
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  // Formats the legend for Companies
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.Valuation_billions));
  
  legend.append("text")
  	.attr("x", 300)
  	.attr("y", 10)
  	.attr("class","legend_value")
    .style('fill', 'green')
  	.text(d=>xAxisTickFormat((d.data.Valuation_billions))+"B");
  
  // Formats the legend for Companies
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 10)
  	.attr("class","legend_text")
    .style('fill', 'blue')
  	.text(d => d.data.Company);
  
}

// Main function
const run = async () => {
  let data = await fetchData()
  let total = 0
  data.forEach(d=>{
    d.Valuation_billions= +d.Valuation_billions;
    total += d.Valuation_billions
  });
	render(data,total);
};
run();